pub struct ChannelGraph {
pub(crate) me: OffchainPublicKey,
pub(crate) edge_penalty: f64,
pub(crate) min_ack_rate: f64,
pub(crate) inner: Arc<RwLock<InnerGraph>>,
}Expand description
A directed graph representing logical channels between nodes.
The graph is directed, with nodes representing the physical nodes in the network using
their [OffchainPublicKey] as identifier and edges representing the logical channels
between them. Each logical channel aggregates different weighted properties, like
channel capacity (calculated from the on-chain channel balance, ticket price and ticket probability)
and evaluated transport network properties between the nodes.
Interior mutability is provided via an internal [RwLock] so that all trait
methods (which take &self) can safely read and write the graph. In production
code, the graph is expected to be shared behind an Arc<ChannelGraph>.
Fields
me: OffchainPublicKeyedge_penalty: f64min_ack_rate: f64inner: Arc<RwLock<InnerGraph>>Implementations
Sourceimpl ChannelGraph
impl ChannelGraph
Sourcepub fn new(me: OffchainPublicKey) -> Self
pub fn new(me: OffchainPublicKey) -> Self
Creates a new channel graph with the given self identity and default edge scoring parameters (edge_penalty = 0.5, min_ack_rate = 0.1).
The me key represents the local node which is automatically added
to the graph as the first node.
Production code should prefer with_edge_params to
receive values from PathPlannerConfig.
Sourcepub fn with_edge_params(
me: OffchainPublicKey,
edge_penalty: f64,
min_ack_rate: f64,
) -> Self
pub fn with_edge_params( me: OffchainPublicKey, edge_penalty: f64, min_ack_rate: f64, ) -> Self
Creates a new channel graph with custom edge scoring parameters.
me– offchain public key of the local node (added as the first graph node).edge_penalty– penalty multiplier for edges lacking probe-based quality observations.min_ack_rate– minimum acceptable message acknowledgment rate for path selection.